@@ -14,7 +14,8 @@ MainWindow::MainWindow(QWidget *parent) :
     profileWindow(0),
     groupsWindow(0),
     loginWindow(0),
-    eventsWindow(0)
+    eventsWindow(0),
+    nam(new QNetworkAccessManager(this))
 {
     ui->setupUi(this);
 #ifdef Q_WS_MAEMO_5
@@ -35,6 +36,7 @@ MainWindow::MainWindow(QWidget *parent) :
         }
         notificationsDialog = new NotificationsDialog(this, accessToken);
         connect(ui->pushButton, SIGNAL(clicked()), notificationsDialog, SLOT(show()));
+        connect(notificationsDialog, SIGNAL(gotNotificationsCount(int)), this, SLOT(onGotNotificationCount(int)));
     }
 #ifdef Q_WS_MAEMO_5
     QTimer::singleShot(1200, this, SLOT(takeScreenshot()));
@@ -120,6 +122,13 @@ void MainWindow::onItemActivated(QListWidgetItem *item)
         eventsWindow->showMaximized();
 #else
         eventsWindow->show();
+#endif
+    } else if (item->text() == tr("Places")) {
+        PlacesWindow *placesWindow = new PlacesWindow(this, this->accessToken);
+#ifdef Q_WS_S60
+        placesWindow->showMaximized();
+#else
+        placesWindow->show();
 #endif
     }
 }
@@ -129,6 +138,32 @@ void MainWindow::orientationChanged()
     ui->listWidget->setFlow(ui->listWidget->flow());
 }
 
+void MainWindow::createFavorites()
+{
+
+}
+
+void MainWindow::getRequestsCount()
+{
+    QString url = QString("https://api.facebook.com/method/notifications.get&access_token=%1").arg(accessToken);
+    requestsReply = nam->get(QNetworkRequest(url));
+    if (requestsReply)
+        connect(requestsReply, SIGNAL(finished()), this, SLOT(onGotRequestCount()));
+}
+
+void MainWindow::onGotRequestCount()
+{
+
+}
+
+void MainWindow::onGotNotificationCount(int count)
+{
+    if (count == 0)
+        ui->pushButton->setText(tr("Notifications"));
+    else
+        ui->pushButton->setText(tr("Notifications (%1)").arg(count));
+}
+
 void MainWindow::createLoginWindow()
 {
     if (!loginWindow) {
@@ -176,12 +211,15 @@ void MainWindow::onGetMyIdReply()
     this->myName = jsonData.toMap().value("name").toString();
     this->myId = jsonData.toMap().value("id").toString();
 #ifdef Q_WS_MAEMO_5
-    QMaemo5InformationBox::information(this, tr("Logged in as") + QString(" %1").arg(myName));
+    QMaemo5InformationBox::information(this, tr("Logged in as %1").arg(myName));
 #endif
     QSettings().setValue("main/myName", this->myName);
     QSettings().setValue("main/myId", this->myId);
     disconnect(reply, SIGNAL(finished()), this, SLOT(onGetMyIdReply()));
     qfacebook->deleteLater();
+    notificationsDialog = new NotificationsDialog(this, accessToken);
+    connect(ui->pushButton, SIGNAL(clicked()), notificationsDialog, SLOT(show()));
+    connect(notificationsDialog, SIGNAL(gotNotificationsCount(int)), this, SLOT(onGotNotificationCount(int)));
 }
 
 void MainWindow::deleteWindows()
