@@ -5,6 +5,8 @@
 #include <QTimer>
 #include <QSettings>
 #include <QListWidgetItem>
+#include <QNetworkReply>
+#include <QNetworkAccessManager>
 #include "loginwindow.h"
 #include "friendswindow.h"
 #include "newsfeedwindow.h"
@@ -13,6 +15,7 @@
 #include "notificationsdialog.h"
 #include "groupswindow.h"
 #include "eventswindow.h"
+#include "placeswindow.h"
 #include "delegates/thumbnailitemdelegate.h"
 
 namespace Ui {
@@ -43,6 +46,8 @@ private:
     LoginWindow *loginWindow;
     EventsWindow *eventsWindow;
     NotificationsDialog *notificationsDialog;
+    QNetworkAccessManager *nam;
+    QNetworkReply *requestsReply;
     void getMyId();
 
 private slots:
@@ -53,6 +58,11 @@ private slots:
     void onItemActivated(QListWidgetItem *item);
     void orientationChanged();
     void onGetMyIdReply();
+    void createFavorites();
+    void onGotNotificationCount(int count);
+    void getRequestsCount();
+    void onGotRequestCount();
+
 #ifdef Q_WS_MAEMO_5
     void takeScreenshot();
 #endif
