@@ -101,6 +101,11 @@ void NewsFeedPost::setTime(QString time)
     ui->timeLabel->setText(date);
 }
 
+void NewsFeedPost::setTimeFromString(QString timeAsString)
+{
+    ui->timeLabel->setText(timeAsString);
+}
+
 void NewsFeedPost::setDeletable(bool deletable)
 {
     this->isDeletable = deletable;
@@ -165,6 +170,12 @@ void NewsFeedPost::setCommentMode(bool isComment)
     ui->commentButton->setHidden(isComment);
 }
 
+void NewsFeedPost::setMessageMode(bool isMessage)
+{
+    ui->commentButton->setHidden(isMessage);
+    ui->likeButton->setHidden(isMessage);
+}
+
 void NewsFeedPost::avatarReceived()
 {
     QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
@@ -236,3 +247,22 @@ void NewsFeedPost::paintEvent(QPaintEvent *)
     painter.drawLine(QPoint(this->geometry().left(), this->geometry().bottom()-2),
                      QPoint(this->geometry().right() ,this->geometry().bottom()-2));*/
 }
+
+void NewsFeedPost::mousePressEvent(QMouseEvent *ev)
+{
+    if (ev->button() == Qt::LeftButton) {
+        m_pressed = true;
+        emit pressed();
+    }
+}
+
+void NewsFeedPost::mouseReleaseEvent(QMouseEvent *ev)
+{
+    if (ev->button() == Qt::LeftButton) {
+        m_pressed = false;
+        emit released();
+        if (rect().contains(ev->pos())) {
+            emit clicked(id);
+        }
+    }
+}
