@@ -78,17 +78,17 @@ void ProfileWindow::onInfoReplyReceived()
     if (fromLocation.isEmpty())
         ui->fromLabel->hide();
     else
-        ui->fromLabel->setText(tr("From") + QString(" %1").arg(fromLocation));
+        ui->fromLabel->setText(tr("From %1").arg(fromLocation));
 
     if (currentLocation.isEmpty())
         ui->locationLabel->hide();
     else
-        ui->locationLabel->setText(tr("Lives in") + QString(" %1").arg(currentLocation));
+        ui->locationLabel->setText(tr("Lives in %1").arg(currentLocation));
 
     if (birthday.isEmpty())
         ui->birthdateLabel->hide();
     else
-        ui->birthdateLabel->setText(tr("Born on") + QString(" %1").arg(birthday));
+        ui->birthdateLabel->setText(tr("Born on %1").arg(birthday));
 }
 
 void ProfileWindow::onAvatarClicked()
@@ -160,9 +160,10 @@ void ProfileWindow::onReplyReceived()
         QString icon = jsonData.toMap().value("icon").toString();
         QString time = jsonData.toMap().value("created_time").toString();
         QString link = jsonData.toMap().value("link").toString();
+        if (link.isEmpty())
+            link = jsonData.toMap().value("source").toString();
         if (!link.isEmpty()) {
-            message.append("\nAttached links:\n");
-            message.append(link + "\n");
+            message.append(QString("<a href=\"%1\">%1</a>").arg(link));
             message.append(jsonData.toMap().value("name").toString() + "\n");
             message.append(jsonData.toMap().value("caption").toString() + "\n");
             message.append(jsonData.toMap().value("description").toString() + "\n");
